@@ -12,6 +12,7 @@ import tqdm
 import time
 import copy
 import types
+import traceback
 from collections import defaultdict
 from pathlib import Path
 
@@ -26,6 +27,32 @@ from . import io_tools as io
 from . import util
 from . import core
 
+# helper funtions
+def restore_source(repoName):
+    """
+    Restores the data respository based on the last working git hash in the inventory file.
+    After a successfulr restorations, datatoolbox need to be imported from scratch. For notebooks
+    the restart of the kernal might be required.
+
+    Parameters
+    ----------
+    repoName : str
+        Source ID.
+
+    Returns
+    -------
+    None.
+
+    """
+    
+    #gitManager = GitRepository_Manager(config)
+    #sources   = gitManager.sources
+    sources = pd.read_csv(config.SOURCE_FILE, index_col='SOURCE_ID')
+    git_hash = sources.git_commit_hash.loc[repoName]
+    repoPath = os.path.join(config.PATH_TO_DATASHELF,  'database', repoName)
+    git_repo = git.Repo(repoPath)
+    git_repo.git.execute(['git', 'reset', '--hard', git_hash])
+            
 class Database():
     """
     CSV based database that uses git for as distributed version control system.
@@ -325,8 +352,10 @@ class Database():
                 
                     filePath = self._getTableFilePath(ID)
                     return read_csv(filePath)
-            except:
+            except Exception:
+                
                 if config.DEBUG:
+                    print(traceback.format_exc())
                     print('Failed to import source {}'.format(source))
         
         raise(BaseException('Table {} not found'.format(ID)))
@@ -890,6 +919,28 @@ class Database():
         print('export successful: ({})'.format( config.DATASHELF_REMOTE +  sourceID))
         
 
+    def pull_update_from_remote(self, repoName):
+        """
+        Updates the local data repository by the newest version on the remote repository
+        
+
+        Parameters
+        ----------
+        repoName : str
+            Source ID string to identify which source repository should be updated.
+
+        Returns
+        -------
+        None.
+
+        """
+        new_inventory = self.gitManager.pull_update_from_remote(repoName,self.inventory)
+        self.inventory = new_inventory
+        
+        self._gitCommit('udpate from remote')
+        
+        
+        
 #%%
 class GitRepository_Manager:
     """
@@ -1077,9 +1128,18 @@ class GitRepository_Manager:
         repoName : str - valid repository in the remove database
         repoPath : str - path of the repository
         """
-        
-        url = config.DATASHELF_REMOTE + repoName + '.git'
-        repo = git.Repo.clone_from(url=url, to_path=repoPath, progress=TqdmProgressPrinter())  
+        try:
+            print('Try cloning source via ssh')
+            url = config.DATASHELF_REMOTE + repoName + '.git'
+            repo = git.Repo.clone_from(url=url, to_path=repoPath, progress=TqdmProgressPrinter())  
+        except:
+            
+            print('Failed... Try Cloning source via https:')
+            url = config.DATASHELF_REMOTE_HTTPS + repoName + '.git'
+            repo = git.Repo.clone_from(url=url, to_path=repoPath, progress=TqdmProgressPrinter())
+            
+            
+                    
         self.repositories[repoName] = repo
 
         # Update source file
@@ -1091,7 +1151,7 @@ class GitRepository_Manager:
 
         return repo
         
-    def pull_update_from_remote(self, repoName):
+    def pull_update_from_remote(self, repoName, old_inventory):
         """
         This function used git pull an updated remote source dataset to the local
         database.
@@ -1104,7 +1164,15 @@ class GitRepository_Manager:
         """
         self[repoName].remote('origin').pull(progress=TqdmProgressPrinter())
         self.updateGitHash(repoName)
-        self.commit('udpate from remote')
+        repoPath = os.path.join(self.PATH_TO_DATASHELF,  'database', repoName)
+        sourceInventory = pd.read_csv(os.path.join(repoPath, 'source_inventory.csv'), index_col=0, dtype={'source_year': str})
+        new_inventory = pd.concat([
+            old_inventory[old_inventory["source"] != repoName],
+            sourceInventory
+        ])
+
+        
+        return new_inventory
     
     def verifyGitHash(self, repoName):
         """
